@@ -1,5 +1,8 @@
 from dataclasses import dataclass
-from typing import Callable
+from typing import (
+    Callable
+)
+from pathlib import Path
 
 StrAlias = str
 # This is very important value
@@ -45,6 +48,19 @@ class KlassWithDecorator:
     pass
 
 
+"""
+    class with comment and decorator
+from this import is dummy
+def this_is_comment():
+    pass
+"""
+
+
+@dataclass(frozen=True)
+class KlassWithCommentAndDecorator:
+    pass
+
+
 class KlassWithMember:
     value: StrAlias
     meta: KlassWithMetaKlass
@@ -64,7 +80,7 @@ def _function_start_with_underscore(klass: KlassWithComment2):
 """
 
 
-def function_with_comment1():
+def function_with_comment1(path: Path):
     pass
 
 
@@ -89,5 +105,11 @@ def function_with_decorator():
     pass
 
 
+# this comment for function_with_comment_and_decorator
+@staticmethod
+def function_with_comment_and_decorator():
+    pass
+
+
 async def function_with_async():
     pass
